LanguagePickerDropdown class

Provides a customizable DropdownButton for all languages

Inheritance

Constructors

LanguagePickerDropdown({Key? key, ItemBuilder? itemBuilder, String? initialValue, ValueChanged<Language>? onValuePicked, List<Language>? languages, LanguagePickerDropdownController? controller, @Deprecated('Use languages instead. Will be removed in 0.5.0.') List<Map<String, String>>? languagesList})
Creates a dropdown of languages.
const

Properties

controller → LanguagePickerDropdownController?
Lets you read and change the selection from outside this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
initialValue → String?
It should be one of the ISO 639-1 codes of languages.
final
itemBuilder → ItemBuilder?
This function will be called to build the child of DropdownMenuItem If it is not provided, default one will be used which displays the name and the isoCode in a row. Check _buildDefaultMenuItem method for details.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
languages → List<Language>?
List of languages available in this picker.
final
languagesList → List<Map<String, String>>?
List of languages available in this picker, as maps.
final
onValuePicked → ValueChanged<Language>?
This function will be called whenever a Language item is selected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LanguagePickerDropdown>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited