controller property
Lets you read and change the selection from outside this widget.
initialValue is ignored when this is given.
Implementation
final LanguagePickerDropdownController? controller;
Lets you read and change the selection from outside this widget.
initialValue is ignored when this is given.
final LanguagePickerDropdownController? controller;