LanguagePickerDropdownController class
Lets you read and change the selection of a LanguagePickerDropdown from outside the widget.
final controller = LanguagePickerDropdownController();
...
LanguagePickerDropdown(controller: controller)
...
controller.selectIsoCode('ko'); // the dropdown follows
print(controller.value.name); // reads the current selection
Call dispose when you are done with it.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
Language> - LanguagePickerDropdownController
Constructors
- LanguagePickerDropdownController({Language? initialValue})
-
Creates a controller selecting
initialValue.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Language
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
selectIsoCode(
String isoCode) → void - Selects the language with the given ISO 639-1 code.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited