LanguagePickerDropdownController constructor

LanguagePickerDropdownController({
  1. Language? initialValue,
})

Creates a controller selecting initialValue.

initialValue defaults to Languages.english.

If the dropdown this controller is given to does not have the selected language in its list, the controller is moved to the language the dropdown ends up showing.

Implementation

LanguagePickerDropdownController({Language? initialValue})
    : super(initialValue ?? Languages.english);