LanguagePickerUtils class

Helpers of this package.

Constructors

LanguagePickerUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getFlagImageAssetPath(String isoCode) → String
The asset path of the flag image of isoCode.
getLanguageByIsoCode(String isoCode) → Language
Finds a language by its ISO 639-1 code.