LanguagePickerDropdown class
Provides a customizable DropdownButton for all languages
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LanguagePickerDropdown
Constructors
-
LanguagePickerDropdown({Key? key, ItemBuilder? itemBuilder, String? initialValue, ValueChanged<
Language> ? onValuePicked, List<Map< ? languagesList})String, String> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
It should be one of the ISO ALPHA-2 Code that is provided
in languagesList map of languages.dart file.
final
- itemBuilder → ItemBuilder?
-
This function will be called to build the child of DropdownMenuItem
If it is not provided, default one will be used which displays
flag image, isoCode and phoneCode in a row.
Check _buildDefaultMenuItem method for details.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
languagesList
→ List<
Map< ?String, String> > -
List of languages available in this picker.
final
-
onValuePicked
→ ValueChanged<
Language> ? -
This function will be called whenever a Language item is selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _LanguagePickerDropdownState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited