itemBuilder property
This function will be called to build the child of DropdownMenuItem If it is not provided, default one will be used which displays the name and the isoCode in a row. Check _buildDefaultMenuItem method for details.
Implementation
final ItemBuilder? itemBuilder;